==> colourvalues_0.3.0.tar.gz: colourvalues/inst/include/colourvalues/palettes/magma.hpp <==
#ifndef R_COLOURVALUES_MAGMA_H
#define R_COLOURVALUES_MAGMA_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector magma_red = {
    0.00146159096, 0.00225764007, 0.00327943222, 0.00451230222,
    0.00594976987, 0.0075879855, 0.0094260439, 0.0114654337, 0.0137075706,
    0.0161557566, 0.018815367, 0.021691934, 0.0247917814, 0.0281228154,
    0.0316955304, 0.0355204468, 0.0396084872, 0.043829535, 0.0480616391,
    0.0523204388, 0.0566148978, 0.060949393, 0.0653301801, 0.0697637296,
    0.0742565152, 0.0788150034, 0.0834456313, 0.088154773, 0.0929486914,
    0.097833477, 0.102814972, 0.107898679, 0.113094451, 0.118405035,
    0.123832651, 0.129380192, 0.135053322, 0.140857952, 0.146785234,
    0.152839217, 0.159017511, 0.165308131, 0.171713033, 0.17821173,
    0.184800877, 0.191459745, 0.198176877, 0.204934882, 0.211718061,
    0.21851159, 0.225302032, 0.232076515, 0.238825991, 0.245543175,
    0.252220252, 0.258857304, 0.265446744, 0.271994089, 0.2784933,
    0.284951097, 0.291365817, 0.297740413, 0.304080941, 0.310382027,
    0.316654235, 0.322899126, 0.329114038, 0.335307503, 0.341481725,
    0.347635742, 0.353773161, 0.359897941, 0.366011928, 0.372116205,
    0.378210547, 0.384299445, 0.390384361, 0.39646667, 0.402547663,
    0.408628505, 0.414708664, 0.420791157, 0.426876965, 0.432967001,
    0.439062114, 0.445163096, 0.451270678, 0.457385535, 0.463508291,
    0.469639514, 0.475779723, 0.481928997, 0.488088169, 0.494257673,
    0.500437834, 0.506628929, 0.512831195, 0.519044825, 0.525269968,
    0.531506735, 0.537755194, 0.544015371, 0.550287252, 0.556570783,
    0.562865867, 0.569172368, 0.575490107, 0.581818864, 0.588158375,
    0.594508337, 0.600868399, 0.607238169, 0.613617209, 0.620005032,
    0.626401108, 0.632804854, 0.639215638, 0.645632778, 0.652055535,
    0.658483116, 0.664914668, 0.671349279, 0.677785975, 0.684223712,
    0.69066138, 0.697097796, 0.7035317, 0.709961888, 0.716387038,
    0.722805451, 0.729215521, 0.735615545, 0.742003713, 0.748378107,
    0.754736692, 0.761077312, 0.767397681, 0.77369538, 0.779967847,
    0.786212372, 0.792426972, 0.79860776, 0.804751511, 0.810854841,
    0.816914186, 0.822925797, 0.82888574, 0.834790818, 0.84063568,
    0.846415804, 0.85212649, 0.85776287, 0.863320397, 0.868793368,
    0.874176342, 0.879463944, 0.884650824, 0.889731418, 0.894700194,
    0.899551884, 0.904281297, 0.908883524, 0.913354091, 0.917688852,
    0.921884187, 0.925937102, 0.92984509, 0.933606454, 0.937220874,
    0.940687443, 0.944006448, 0.947179528, 0.95021015, 0.953099077,
    0.955849237, 0.958464079, 0.960949221, 0.963310281, 0.965549351,
    0.967671128, 0.969680441, 0.971582181, 0.973381238, 0.975082439,
    0.976690494, 0.978209957, 0.979645181, 0.981000291, 0.982279159,
    0.983485387, 0.984622298, 0.985692925, 0.986700017, 0.987646038,
    0.988533173, 0.989363341, 0.990138201, 0.990871208, 0.991558165,
    0.992195728, 0.992784669, 0.993325561, 0.993834412, 0.994308514,
    0.994737698, 0.995121854, 0.995480469, 0.995809924, 0.996095703,
    0.996341406, 0.996579803, 0.996774784, 0.996925427, 0.997077185,
    0.997186253, 0.997253982, 0.99732518, 0.997350983, 0.997350583,
    0.997341259, 0.997284689, 0.997228367, 0.99713848, 0.997019342,
    0.996898254, 0.996726862, 0.996570645, 0.996369065, 0.996162309,
    0.995932448, 0.995680107, 0.995423973, 0.995131288, 0.994851089,
    0.994523666, 0.9942219, 0.993865767, 0.993545285, 0.993169558,
    0.992830963, 0.992439881, 0.992089454, 0.991687744, 0.991331929,
    0.990929685, 0.990569914, 0.990174637, 0.989814839, 0.989433736,
    0.989077438, 0.988717064, 0.988367028, 0.988032885, 0.987690702,
    0.987386827, 0.987052509
  };

  const Rcpp::NumericVector magma_green = {
    0.000466127766, 0.00129495431, 0.00230452991, 0.00349037666,
    0.00484285, 0.00635613622, 0.00802185006, 0.00982831486, 0.0117705913,
    0.0138404966, 0.0160262753, 0.0183201254, 0.0207147875, 0.0232009284,
    0.0257651161, 0.028397457, 0.0310895652, 0.0338299885, 0.0366066101,
    0.039406602, 0.0421598925, 0.0447944924, 0.0473177796, 0.0497264666,
    0.0520167766, 0.0541844801, 0.0562249365, 0.0581331465, 0.0599038167,
    0.0615314414, 0.0630104053, 0.0643351102, 0.0654920358, 0.0664791593,
    0.0672946449, 0.0679349264, 0.0683912798, 0.068654071, 0.0687382323,
    0.0686368599, 0.0683540225, 0.0679108689, 0.067305326, 0.0665758073,
    0.0657324381, 0.0648183312, 0.0638624166, 0.0629066192, 0.0619917876,
    0.0611584918, 0.0604451843, 0.0598886855, 0.0595170384, 0.0593524384,
    0.0594147119, 0.0597055998, 0.0602368754, 0.0609935552, 0.0619778136,
    0.0631676261, 0.0645534486, 0.0661170432, 0.0678353452, 0.0697024767,
    0.0716895272, 0.0737819504, 0.0759715081, 0.0782361045, 0.0805635079,
    0.0829463512, 0.0853726329, 0.0878311772, 0.0903143031, 0.0928159917,
    0.0953322947, 0.0978549106, 0.100379466, 0.102902194, 0.105419865,
    0.107929771, 0.110431177, 0.11292021, 0.115395258, 0.117854987,
    0.120298314, 0.122724371, 0.125132484, 0.127522145, 0.129892998,
    0.132244819, 0.1345775, 0.13689139, 0.139186217, 0.141462106,
    0.143719323, 0.145958202, 0.148179144, 0.150382611, 0.152569121,
    0.154739247, 0.156893613, 0.159032895, 0.161157816, 0.163269149,
    0.165367714, 0.167454379, 0.169530062, 0.171595728, 0.173652392,
    0.175701122, 0.177743036, 0.179779309, 0.18181117, 0.183839907,
    0.185866869, 0.187893468, 0.189921182, 0.191951556, 0.19398621,
    0.196026835, 0.198075202, 0.200133166, 0.202202663, 0.204285721,
    0.206384461, 0.2085011, 0.210637956, 0.212797337, 0.214981693,
    0.217193831, 0.219436516, 0.221712634, 0.224025196, 0.226377345,
    0.228772352, 0.231213625, 0.233704708, 0.236249283, 0.23885117,
    0.241514325, 0.24424225, 0.247039798, 0.24991135, 0.252861399,
    0.25589455, 0.259015505, 0.262229049, 0.265539703, 0.268952874,
    0.272473491, 0.276106469, 0.279856666, 0.283729003, 0.287728205,
    0.291858679, 0.296124596, 0.30053009, 0.305078817, 0.309773445,
    0.314616425, 0.319609981, 0.324755126, 0.330051947, 0.335500068,
    0.341098112, 0.346843685, 0.352733817, 0.358764377, 0.364929312,
    0.371224168, 0.377642889, 0.384177874, 0.390819546, 0.397562894,
    0.404400213, 0.411323666, 0.418323245, 0.425389724, 0.432518707,
    0.439702976, 0.446935635, 0.45421017, 0.461520484, 0.468860936,
    0.47622635, 0.483612031, 0.491013764, 0.4984278, 0.505850848,
    0.513280054, 0.520712972, 0.528147545, 0.53558207, 0.543015173,
    0.550445778, 0.557873075, 0.565296495, 0.572706259, 0.580106828,
    0.587501706, 0.594891088, 0.602275297, 0.60964354, 0.616998953,
    0.624349657, 0.631696376, 0.639026596, 0.646343897, 0.653658756,
    0.660969379, 0.668255621, 0.675541484, 0.682827953, 0.690087897,
    0.697348991, 0.704610791, 0.711847714, 0.719089119, 0.726324415,
    0.733544671, 0.740771893, 0.747980563, 0.755189852, 0.762397883,
    0.769590975, 0.77679486, 0.783976508, 0.791167346, 0.798347709,
    0.805527126, 0.812705773, 0.819875302, 0.827051773, 0.834212826,
    0.841386618, 0.848540474, 0.855711038, 0.862858846, 0.870024467,
    0.877168404, 0.884329694, 0.891469549, 0.89862705, 0.905762748,
    0.91291501, 0.920048699, 0.927195612, 0.93432854, 0.941470354,
    0.948604077, 0.95574152, 0.962878026, 0.970012413, 0.977154231,
    0.984287561, 0.991437853
  };

  const Rcpp::NumericVector magma_blue = {
    0.01386552, 0.0183311461, 0.0237083291, 0.0299647059, 0.0371296695,
    0.0449730774, 0.0528443561, 0.060749638, 0.0686665843, 0.076602666,
    0.0845844897, 0.092610105, 0.100675555, 0.108786954, 0.116964722,
    0.125209396, 0.133515085, 0.141886249, 0.150326989, 0.158841025,
    0.167445592, 0.176128834, 0.184891506, 0.193735088, 0.202660374,
    0.211667355, 0.220755099, 0.229921611, 0.239163669, 0.248476662,
    0.2578544, 0.267288933, 0.276783978, 0.286320656, 0.295879431,
    0.305442931, 0.31499989, 0.32453764, 0.334011109, 0.34340445,
    0.352688028, 0.361816426, 0.370770827, 0.379497161, 0.387972507,
    0.396151969, 0.404008953, 0.411514273, 0.418646741, 0.425391816,
    0.431741767, 0.437694665, 0.443255999, 0.448435938, 0.453247729,
    0.457709924, 0.461840297, 0.465660375, 0.469190328, 0.472450879,
    0.475462193, 0.478243482, 0.480811572, 0.48318634, 0.485380429,
    0.487408399, 0.489286796, 0.491024144, 0.492631321, 0.494120923,
    0.495501096, 0.496778331, 0.497959963, 0.499053326, 0.500066568,
    0.501001964, 0.501864236, 0.50265759, 0.503385761, 0.504052118,
    0.504661843, 0.505214935, 0.505713602, 0.506159754, 0.506555026,
    0.506900806, 0.507198258, 0.507448336, 0.507651812, 0.507809282,
    0.507921193, 0.507988509, 0.508010737, 0.507987836, 0.507919772,
    0.50780642, 0.50764757, 0.507442938, 0.507192172, 0.50689486,
    0.506550538, 0.506158696, 0.505718782, 0.50523021, 0.504692365,
    0.504104606, 0.503466273, 0.50277669, 0.502035167, 0.501241011,
    0.500393522, 0.499491999, 0.498535746, 0.497524075, 0.496456304,
    0.495331769, 0.494149821, 0.492909832, 0.491611196, 0.490253338,
    0.488835712, 0.487357807, 0.485819154, 0.484219325, 0.482557941,
    0.480834678, 0.47904927, 0.477201121, 0.47528978, 0.473315708,
    0.471278924, 0.469179541, 0.467017774, 0.464793954, 0.462508534,
    0.460162106, 0.457755411, 0.455289354, 0.452765022, 0.450183695,
    0.447543155, 0.444848441, 0.442101615, 0.439304963, 0.436461074,
    0.433572874, 0.430643647, 0.427671352, 0.42466562, 0.421631064,
    0.418572767, 0.415496319, 0.412402889, 0.409303002, 0.406205397,
    0.403118034, 0.40004706, 0.397001559, 0.393994634, 0.391036674,
    0.388136889, 0.385308008, 0.382563414, 0.379915138, 0.377375977,
    0.374959077, 0.372676513, 0.370540883, 0.368566525, 0.366761699,
    0.365136328, 0.36370113, 0.362467694, 0.361438431, 0.360619076,
    0.360014232, 0.359629789, 0.35946902, 0.359529151, 0.359810172,
    0.36031112, 0.361030156, 0.361964652, 0.363111292, 0.364466162,
    0.366024854, 0.367782559, 0.369734157, 0.371874301, 0.374197501,
    0.376698186, 0.379370774, 0.382209724, 0.385209578, 0.388365009,
    0.391670846, 0.395122099, 0.398713971, 0.402441058, 0.406298792,
    0.410282976, 0.414389658, 0.418613221, 0.422949672, 0.427396771,
    0.431951492, 0.436607159, 0.441360951, 0.446213021, 0.451160201,
    0.456191814, 0.461314158, 0.466525689, 0.471811461, 0.477181727,
    0.482634651, 0.488154375, 0.493754665, 0.499427972, 0.505166839,
    0.510983331, 0.516859378, 0.522805996, 0.528820775, 0.534892341,
    0.541038571, 0.547232992, 0.553498939, 0.559819643, 0.566201824,
    0.572644795, 0.57914013, 0.585701463, 0.592307093, 0.598982818,
    0.605695903, 0.612481798, 0.6192993, 0.626189463, 0.633109148,
    0.640099465, 0.647116021, 0.654201544, 0.661308839, 0.668481201,
    0.675674592, 0.682925602, 0.690198194, 0.697518628, 0.704862519,
    0.712242232, 0.719648627, 0.727076773, 0.734536205, 0.742001547,
    0.749504188
  };

  const Rcpp::List magma = Rcpp::List::create(
    Rcpp::_["r"] = magma_red,
    Rcpp::_["g"] = magma_green,
    Rcpp::_["b"] = magma_blue
  );
} // namespace palette
} // namepsace colourvalues
#endif

==> colourvalues_0.3.9.tar.gz: colourvalues/inst/include/colourvalues/palettes/magma.hpp <==
#ifndef R_COLOURVALUES_MAGMA_H
#define R_COLOURVALUES_MAGMA_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector magma_red = {
    0.00146159096, 0.00225764007, 0.00327943222, 0.00451230222,
    0.00594976987, 0.0075879855, 0.0094260439, 0.0114654337, 0.0137075706,
    0.0161557566, 0.018815367, 0.021691934, 0.0247917814, 0.0281228154,
    0.0316955304, 0.0355204468, 0.0396084872, 0.043829535, 0.0480616391,
    0.0523204388, 0.0566148978, 0.060949393, 0.0653301801, 0.0697637296,
    0.0742565152, 0.0788150034, 0.0834456313, 0.088154773, 0.0929486914,
    0.097833477, 0.102814972, 0.107898679, 0.113094451, 0.118405035,
    0.123832651, 0.129380192, 0.135053322, 0.140857952, 0.146785234,
    0.152839217, 0.159017511, 0.165308131, 0.171713033, 0.17821173,
    0.184800877, 0.191459745, 0.198176877, 0.204934882, 0.211718061,
    0.21851159, 0.225302032, 0.232076515, 0.238825991, 0.245543175,
    0.252220252, 0.258857304, 0.265446744, 0.271994089, 0.2784933,
    0.284951097, 0.291365817, 0.297740413, 0.304080941, 0.310382027,
    0.316654235, 0.322899126, 0.329114038, 0.335307503, 0.341481725,
    0.347635742, 0.353773161, 0.359897941, 0.366011928, 0.372116205,
    0.378210547, 0.384299445, 0.390384361, 0.39646667, 0.402547663,
    0.408628505, 0.414708664, 0.420791157, 0.426876965, 0.432967001,
    0.439062114, 0.445163096, 0.451270678, 0.457385535, 0.463508291,
    0.469639514, 0.475779723, 0.481928997, 0.488088169, 0.494257673,
    0.500437834, 0.506628929, 0.512831195, 0.519044825, 0.525269968,
    0.531506735, 0.537755194, 0.544015371, 0.550287252, 0.556570783,
    0.562865867, 0.569172368, 0.575490107, 0.581818864, 0.588158375,
    0.594508337, 0.600868399, 0.607238169, 0.613617209, 0.620005032,
    0.626401108, 0.632804854, 0.639215638, 0.645632778, 0.652055535,
    0.658483116, 0.664914668, 0.671349279, 0.677785975, 0.684223712,
    0.69066138, 0.697097796, 0.7035317, 0.709961888, 0.716387038,
    0.722805451, 0.729215521, 0.735615545, 0.742003713, 0.748378107,
    0.754736692, 0.761077312, 0.767397681, 0.77369538, 0.779967847,
    0.786212372, 0.792426972, 0.79860776, 0.804751511, 0.810854841,
    0.816914186, 0.822925797, 0.82888574, 0.834790818, 0.84063568,
    0.846415804, 0.85212649, 0.85776287, 0.863320397, 0.868793368,
    0.874176342, 0.879463944, 0.884650824, 0.889731418, 0.894700194,
    0.899551884, 0.904281297, 0.908883524, 0.913354091, 0.917688852,
    0.921884187, 0.925937102, 0.92984509, 0.933606454, 0.937220874,
    0.940687443, 0.944006448, 0.947179528, 0.95021015, 0.953099077,
    0.955849237, 0.958464079, 0.960949221, 0.963310281, 0.965549351,
    0.967671128, 0.969680441, 0.971582181, 0.973381238, 0.975082439,
    0.976690494, 0.978209957, 0.979645181, 0.981000291, 0.982279159,
    0.983485387, 0.984622298, 0.985692925, 0.986700017, 0.987646038,
    0.988533173, 0.989363341, 0.990138201, 0.990871208, 0.991558165,
    0.992195728, 0.992784669, 0.993325561, 0.993834412, 0.994308514,
    0.994737698, 0.995121854, 0.995480469, 0.995809924, 0.996095703,
    0.996341406, 0.996579803, 0.996774784, 0.996925427, 0.997077185,
    0.997186253, 0.997253982, 0.99732518, 0.997350983, 0.997350583,
    0.997341259, 0.997284689, 0.997228367, 0.99713848, 0.997019342,
    0.996898254, 0.996726862, 0.996570645, 0.996369065, 0.996162309,
    0.995932448, 0.995680107, 0.995423973, 0.995131288, 0.994851089,
    0.994523666, 0.9942219, 0.993865767, 0.993545285, 0.993169558,
    0.992830963, 0.992439881, 0.992089454, 0.991687744, 0.991331929,
    0.990929685, 0.990569914, 0.990174637, 0.989814839, 0.989433736,
    0.989077438, 0.988717064, 0.988367028, 0.988032885, 0.987690702,
    0.987386827, 0.987052509
  };

  const Rcpp::NumericVector magma_green = {
    0.000466127766, 0.00129495431, 0.00230452991, 0.00349037666,
    0.00484285, 0.00635613622, 0.00802185006, 0.00982831486, 0.0117705913,
    0.0138404966, 0.0160262753, 0.0183201254, 0.0207147875, 0.0232009284,
    0.0257651161, 0.028397457, 0.0310895652, 0.0338299885, 0.0366066101,
    0.039406602, 0.0421598925, 0.0447944924, 0.0473177796, 0.0497264666,
    0.0520167766, 0.0541844801, 0.0562249365, 0.0581331465, 0.0599038167,
    0.0615314414, 0.0630104053, 0.0643351102, 0.0654920358, 0.0664791593,
    0.0672946449, 0.0679349264, 0.0683912798, 0.068654071, 0.0687382323,
    0.0686368599, 0.0683540225, 0.0679108689, 0.067305326, 0.0665758073,
    0.0657324381, 0.0648183312, 0.0638624166, 0.0629066192, 0.0619917876,
    0.0611584918, 0.0604451843, 0.0598886855, 0.0595170384, 0.0593524384,
    0.0594147119, 0.0597055998, 0.0602368754, 0.0609935552, 0.0619778136,
    0.0631676261, 0.0645534486, 0.0661170432, 0.0678353452, 0.0697024767,
    0.0716895272, 0.0737819504, 0.0759715081, 0.0782361045, 0.0805635079,
    0.0829463512, 0.0853726329, 0.0878311772, 0.0903143031, 0.0928159917,
    0.0953322947, 0.0978549106, 0.100379466, 0.102902194, 0.105419865,
    0.107929771, 0.110431177, 0.11292021, 0.115395258, 0.117854987,
    0.120298314, 0.122724371, 0.125132484, 0.127522145, 0.129892998,
    0.132244819, 0.1345775, 0.13689139, 0.139186217, 0.141462106,
    0.143719323, 0.145958202, 0.148179144, 0.150382611, 0.152569121,
    0.154739247, 0.156893613, 0.159032895, 0.161157816, 0.163269149,
    0.165367714, 0.167454379, 0.169530062, 0.171595728, 0.173652392,
    0.175701122, 0.177743036, 0.179779309, 0.18181117, 0.183839907,
    0.185866869, 0.187893468, 0.189921182, 0.191951556, 0.19398621,
    0.196026835, 0.198075202, 0.200133166, 0.202202663, 0.204285721,
    0.206384461, 0.2085011, 0.210637956, 0.212797337, 0.214981693,
    0.217193831, 0.219436516, 0.221712634, 0.224025196, 0.226377345,
    0.228772352, 0.231213625, 0.233704708, 0.236249283, 0.23885117,
    0.241514325, 0.24424225, 0.247039798, 0.24991135, 0.252861399,
    0.25589455, 0.259015505, 0.262229049, 0.265539703, 0.268952874,
    0.272473491, 0.276106469, 0.279856666, 0.283729003, 0.287728205,
    0.291858679, 0.296124596, 0.30053009, 0.305078817, 0.309773445,
    0.314616425, 0.319609981, 0.324755126, 0.330051947, 0.335500068,
    0.341098112, 0.346843685, 0.352733817, 0.358764377, 0.364929312,
    0.371224168, 0.377642889, 0.384177874, 0.390819546, 0.397562894,
    0.404400213, 0.411323666, 0.418323245, 0.425389724, 0.432518707,
    0.439702976, 0.446935635, 0.45421017, 0.461520484, 0.468860936,
    0.47622635, 0.483612031, 0.491013764, 0.4984278, 0.505850848,
    0.513280054, 0.520712972, 0.528147545, 0.53558207, 0.543015173,
    0.550445778, 0.557873075, 0.565296495, 0.572706259, 0.580106828,
    0.587501706, 0.594891088, 0.602275297, 0.60964354, 0.616998953,
    0.624349657, 0.631696376, 0.639026596, 0.646343897, 0.653658756,
    0.660969379, 0.668255621, 0.675541484, 0.682827953, 0.690087897,
    0.697348991, 0.704610791, 0.711847714, 0.719089119, 0.726324415,
    0.733544671, 0.740771893, 0.747980563, 0.755189852, 0.762397883,
    0.769590975, 0.77679486, 0.783976508, 0.791167346, 0.798347709,
    0.805527126, 0.812705773, 0.819875302, 0.827051773, 0.834212826,
    0.841386618, 0.848540474, 0.855711038, 0.862858846, 0.870024467,
    0.877168404, 0.884329694, 0.891469549, 0.89862705, 0.905762748,
    0.91291501, 0.920048699, 0.927195612, 0.93432854, 0.941470354,
    0.948604077, 0.95574152, 0.962878026, 0.970012413, 0.977154231,
    0.984287561, 0.991437853
  };

  const Rcpp::NumericVector magma_blue = {
    0.01386552, 0.0183311461, 0.0237083291, 0.0299647059, 0.0371296695,
    0.0449730774, 0.0528443561, 0.060749638, 0.0686665843, 0.076602666,
    0.0845844897, 0.092610105, 0.100675555, 0.108786954, 0.116964722,
    0.125209396, 0.133515085, 0.141886249, 0.150326989, 0.158841025,
    0.167445592, 0.176128834, 0.184891506, 0.193735088, 0.202660374,
    0.211667355, 0.220755099, 0.229921611, 0.239163669, 0.248476662,
    0.2578544, 0.267288933, 0.276783978, 0.286320656, 0.295879431,
    0.305442931, 0.31499989, 0.32453764, 0.334011109, 0.34340445,
    0.352688028, 0.361816426, 0.370770827, 0.379497161, 0.387972507,
    0.396151969, 0.404008953, 0.411514273, 0.418646741, 0.425391816,
    0.431741767, 0.437694665, 0.443255999, 0.448435938, 0.453247729,
    0.457709924, 0.461840297, 0.465660375, 0.469190328, 0.472450879,
    0.475462193, 0.478243482, 0.480811572, 0.48318634, 0.485380429,
    0.487408399, 0.489286796, 0.491024144, 0.492631321, 0.494120923,
    0.495501096, 0.496778331, 0.497959963, 0.499053326, 0.500066568,
    0.501001964, 0.501864236, 0.50265759, 0.503385761, 0.504052118,
    0.504661843, 0.505214935, 0.505713602, 0.506159754, 0.506555026,
    0.506900806, 0.507198258, 0.507448336, 0.507651812, 0.507809282,
    0.507921193, 0.507988509, 0.508010737, 0.507987836, 0.507919772,
    0.50780642, 0.50764757, 0.507442938, 0.507192172, 0.50689486,
    0.506550538, 0.506158696, 0.505718782, 0.50523021, 0.504692365,
    0.504104606, 0.503466273, 0.50277669, 0.502035167, 0.501241011,
    0.500393522, 0.499491999, 0.498535746, 0.497524075, 0.496456304,
    0.495331769, 0.494149821, 0.492909832, 0.491611196, 0.490253338,
    0.488835712, 0.487357807, 0.485819154, 0.484219325, 0.482557941,
    0.480834678, 0.47904927, 0.477201121, 0.47528978, 0.473315708,
    0.471278924, 0.469179541, 0.467017774, 0.464793954, 0.462508534,
    0.460162106, 0.457755411, 0.455289354, 0.452765022, 0.450183695,
    0.447543155, 0.444848441, 0.442101615, 0.439304963, 0.436461074,
    0.433572874, 0.430643647, 0.427671352, 0.42466562, 0.421631064,
    0.418572767, 0.415496319, 0.412402889, 0.409303002, 0.406205397,
    0.403118034, 0.40004706, 0.397001559, 0.393994634, 0.391036674,
    0.388136889, 0.385308008, 0.382563414, 0.379915138, 0.377375977,
    0.374959077, 0.372676513, 0.370540883, 0.368566525, 0.366761699,
    0.365136328, 0.36370113, 0.362467694, 0.361438431, 0.360619076,
    0.360014232, 0.359629789, 0.35946902, 0.359529151, 0.359810172,
    0.36031112, 0.361030156, 0.361964652, 0.363111292, 0.364466162,
    0.366024854, 0.367782559, 0.369734157, 0.371874301, 0.374197501,
    0.376698186, 0.379370774, 0.382209724, 0.385209578, 0.388365009,
    0.391670846, 0.395122099, 0.398713971, 0.402441058, 0.406298792,
    0.410282976, 0.414389658, 0.418613221, 0.422949672, 0.427396771,
    0.431951492, 0.436607159, 0.441360951, 0.446213021, 0.451160201,
    0.456191814, 0.461314158, 0.466525689, 0.471811461, 0.477181727,
    0.482634651, 0.488154375, 0.493754665, 0.499427972, 0.505166839,
    0.510983331, 0.516859378, 0.522805996, 0.528820775, 0.534892341,
    0.541038571, 0.547232992, 0.553498939, 0.559819643, 0.566201824,
    0.572644795, 0.57914013, 0.585701463, 0.592307093, 0.598982818,
    0.605695903, 0.612481798, 0.6192993, 0.626189463, 0.633109148,
    0.640099465, 0.647116021, 0.654201544, 0.661308839, 0.668481201,
    0.675674592, 0.682925602, 0.690198194, 0.697518628, 0.704862519,
    0.712242232, 0.719648627, 0.727076773, 0.734536205, 0.742001547,
    0.749504188
  };

  // const Rcpp::List magma = Rcpp::List::create(
  //   Rcpp::_["r"] = magma_red,
  //   Rcpp::_["g"] = magma_green,
  //   Rcpp::_["b"] = magma_blue
  // );
} // namespace palette
} // namepsace colourvalues
#endif
